# function to generate a log for the score scripts

print_text <- function(import, removed = NULL, outliers_1, outliers_2, scores, outliers_3 = NULL, outliers_4 = NULL) {
  log_init_n <- paste("Initial subject count: ",
                      length(unique(import$Subject)), sep = "")
  if (!is.null(removed)) {
    log_remove <- paste("Number of problematic subjects removed: ", 
                        length(unique(removed$Subject)), sep = "")
  } else {
    log_remove <- NULL
  }
  log_outlier_1 <- paste("Number of outliers removed on first pass: ",
                         length(unique(outliers_1$Subject)), sep = "")
  log_outlier_2 <- paste("Number of outliers removed on second pass: ",
                         length(unique(outliers_2$Subject)), sep = "")
  if (!is.null(outliers_3)) {
    log_outlier_3 <- paste("Number of outliers removed on third pass: ",
                           length(unique(outliers_3$Subject)), sep = "")
  } else {
    log_outlier_3 <- NULL
  }
  
  if (!is.null(outliers_4)) {
    log_outlier_4 <- paste("Number of outliers removed on fourth pass: ",
                           length(unique(outliers_4$Subject)), sep = "")
  } else {
    log_outlier_4 <- NULL
  }
  log_final_n <- paste("Final subject count: ", 
                       length(unique(scores$Subject)), sep = "")
  
  cat(log_init_n, log_remove, log_outlier_1, log_outlier_2, log_outlier_3, log_outlier_4, log_final_n, fill = 1)
}

print_removed <- function(removed) {
  removed %>%
    knitr::kable(caption = "Problematic Subjects", digits = 2, format = "html") %>%
    kableExtra::kable_styling(full_width = TRUE) %>%
    kableExtra::scroll_box(width = "100%")
}

print_outliers_1 <- function(outliers_1) {
  outliers_1 %>%
    knitr::kable(caption = "Outliers On First Pass", digits = 2, format = "html") %>%
    kableExtra::kable_styling(full_width = TRUE) %>%
    kableExtra::scroll_box(width = "100%")
}

print_outliers_2 <- function(outliers_2) {
  outliers_2 %>%
    knitr::kable(caption = "Outliers On Second Pass", digits = 2, format = "html") %>%
    kableExtra::kable_styling() %>%
    kableExtra::scroll_box(width = "100%")
}

print_outliers_3 <- function(outliers_3) {
  outliers_3 %>%
    knitr::kable(caption = "Outliers On Third Pass", digits = 2, format = "html") %>%
    kableExtra::kable_styling() %>%
    kableExtra::scroll_box(width = "100%")
}

print_outliers_4 <- function(outliers_4) {
  outliers_4 %>%
    knitr::kable(caption = "Outliers On Fourth Pass", digits = 2, format = "html") %>%
    kableExtra::kable_styling() %>%
    kableExtra::scroll_box(width = "100%")
}
